pub fn outcome_to_exit_code(outcome: CliOutcome) -> i32Expand description
Map an outcome to the stable exit code defined in cli.md.
pub fn outcome_to_exit_code(outcome: CliOutcome) -> i32Map an outcome to the stable exit code defined in cli.md.